@@ -12,7 +12,7 @@
 #include "Client.hpp"
 
 
-void Cast::PushNewMusicDataPacket(ting::Array<ting::byte> d){
+void Cast::PushNewMusicDataPacket(ting::Array<ting::u8> d){
 	this->lastChunkArrivalTimeStamp = ting::GetTicks();
 	this->bufferedChunk = d;//save the chunk as buffered
 
