@@ -26,7 +26,7 @@ class Cast{
 
 	T_ClientsList listeners;
 
-	ting::Array<ting::byte> bufferedChunk;
+	ting::Array<ting::u8> bufferedChunk;
 
 	ting::u32 lastChunkArrivalTimeStamp;
 public:
@@ -43,7 +43,7 @@ public:
 		return this->lastChunkArrivalTimeStamp;
 	}
 
-	void PushNewMusicDataPacket(ting::Array<ting::byte> d);
+	void PushNewMusicDataPacket(ting::Array<ting::u8> d);
 
 	void RemoveListener(ting::Ref<Client>& c);
 	void AddListenerAndSendDataToClient(ting::Ref<Client>& c);
