@@ -17,7 +17,7 @@ using namespace ting;
 
 
 void Client::SendLoginResult(bool success){
-	Array<ting::byte> p(2);
+	Array<ting::u8> p(2);
 
 	p[0] = 0;
 	p[1] = success ? 0 : 1;
@@ -28,9 +28,9 @@ void Client::SendLoginResult(bool success){
 
 
 void Client::SendPlayingPlayer(const std::string& playerNickname){
-	Array<ting::byte> p(1 + 2 + playerNickname.size());
+	Array<ting::u8> p(1 + 2 + playerNickname.size());
 
-	ting::uint i = 0;
+	unsigned i = 0;
 	p[i] = 0x01;
 	++i;
 
@@ -46,7 +46,7 @@ void Client::SendPlayingPlayer(const std::string& playerNickname){
 
 
 void Client::SendStopListening(){
-	Array<ting::byte> p(1);
+	Array<ting::u8> p(1);
 
 	p[0] = 0x02;
 
@@ -56,7 +56,7 @@ void Client::SendStopListening(){
 
 
 void Client::SendRegisterResult(ERegisterRes result){
-	Array<ting::byte> p(2);
+	Array<ting::u8> p(2);
 
 	p[0] = 0x04; //register response
 
