@@ -14,26 +14,52 @@
 
 
 class Client : public cliser::Client{
-	friend class Therver;
+//	friend class Therver;
 
 public:
-	bool isPlaying;
-	T_CastsIter playingCast;
+	enum EState{
+		IDLE,
+		PLAYING,
+		LISTENING,
+		WAITING_FOR_LISTENING
+	};
 
-	bool isListening;
-	T_CastsIter listeningCast;
+private:
+	EState state;
 
+public:
+	inline EState GetState()const{
+		return this->state;
+	}
 
+	void SetState(EState newState);
+
+	T_CastsIter cast; //for PLAYING and LISTENING states
+
+	inline bool IsIdle()const{
+		return this->state == IDLE;
+	}
+
+	inline bool IsWaitingForListening()const{
+		return this->state == WAITING_FOR_LISTENING;
+	}
+
+	inline bool IsListening()const{
+		return this->state == LISTENING;
+	}
+
+	inline bool IsPlaying()const{
+		return this->state == PLAYING;
+	}
 	
 public:
 	Client() :
-			isPlaying(false),
-			isListening(false),
-			state(CONNECTED)
+			state(IDLE),
+			networkState(CONNECTED)
 	{}
 
 
-	enum EState{
+	enum ENetworkState{
 		CONNECTED,
 		LOGGING_IN,
 		LOGGED_IN,
@@ -41,23 +67,23 @@ public:
 	};
 
 
-	inline void SetState(EState s){
-		this->state = s;
+	inline void SetNetworkState(ENetworkState s){
+		this->networkState = s;
 	}
 
-	inline EState GetState()const{
-		return this->state;
+	inline ENetworkState GetNetworkState()const{
+		return this->networkState;
 	}
 
 	inline bool IsLoggedIn()const{
-		return this->GetState() == LOGGED_IN;
+		return this->GetNetworkState() == LOGGED_IN;
 	}
 
 	inline bool IsNotLoggedIn()const{
 		return !this->IsLoggedIn();
 	}
 private:
-	EState state;
+	ENetworkState networkState;
 
 public:
 	std::string username;
