@@ -55,7 +55,7 @@ void Therver::OnClientDisconnected(ting::Ref<cliser::Client>& client){
 
 
 //override
-void Therver::OnDataReceivedFromClient(ting::Ref<cliser::Client>& client, ting::Array<ting::byte> d){
+void Therver::OnDataReceivedFromClient(ting::Ref<cliser::Client>& client, ting::Array<ting::u8> d){
 	ASSERT(client.IsValid())
 	ASSERT(client.DynamicCast<Client>().IsValid())
 	Ref<Client> c = client.StaticCast<Client>();
@@ -107,20 +107,20 @@ void NetworkDataFromClientReceivedMessage::Handle(){
 
 
 
-void Therver::HandleRegisterFromClient(ting::Ref<Client>& c, ting::Array<ting::byte> d){
+void Therver::HandleRegisterFromClient(ting::Ref<Client>& c, ting::Array<ting::u8> d){
 	ASSERT(c)
 	ASSERT(d.Size() > 0)
 	ASSERT(d[0] == 0x04) //4 = register command
 
 	//TODO: ignore if client is logged in
 
-	ting::uint i = 1;
+	unsigned i = 1;
 
 	if(i + 2 > d.Size()){
 		TRACE_AND_LOG(<< "[!WARN] Therver::HandleRegisterFromClient(): bad formed packet 1" << std::endl)
 		return;
 	}
-	ting::uint unLen = ting::FromNetworkFormat16(&d[i]);
+	unsigned unLen = ting::FromNetworkFormat16(&d[i]);
 	i += 2;
 
 	if(unLen == 0){
@@ -141,7 +141,7 @@ void Therver::HandleRegisterFromClient(ting::Ref<Client>& c, ting::Array<ting::b
 		TRACE_AND_LOG(<< "[!WARN] Therver::HandleRegisterFromClient(): bad formed packet 3" << std::endl)
 		return;
 	}
-	ting::uint pwLen = ting::FromNetworkFormat16(&d[i]);
+	unsigned pwLen = ting::FromNetworkFormat16(&d[i]);
 	i += 2;
 
 	if(pwLen == 0){
@@ -172,7 +172,7 @@ void Therver::HandleRegisterFromClient(ting::Ref<Client>& c, ting::Array<ting::b
 
 
 
-void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::byte> p){
+void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::u8> p){
 	ASSERT(c)
 	ASSERT(p.Size() > 0)
 	ASSERT(p[0] == 0)// 0 = login command
@@ -183,7 +183,7 @@ void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::b
 	std::string un;
 	std::string pw;
 
-	ting::uint i = 1;
+	unsigned i = 1;
 
 	//parse username
 	{
@@ -192,7 +192,7 @@ void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::b
 			return;
 		}
 //		TRACE(<< "unLen = " << u32(d[i]) << " " << u32(d[i + 1]) << std::endl)
-		ting::uint usernameLength = ting::FromNetworkFormat16(&p[i]);
+		unsigned usernameLength = ting::FromNetworkFormat16(&p[i]);
 		i += 2;
 
 		if(usernameLength == 0){
@@ -219,7 +219,7 @@ void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::b
 			return;
 		}
 //		TRACE(<< "pwLen = " << u32(d[i]) << " " << u32(d[i + 1]) << std::endl)
-		ting::uint passwordLength = ting::FromNetworkFormat16(&p[i]);
+		unsigned passwordLength = ting::FromNetworkFormat16(&p[i]);
 		i += 2;
 
 		if(passwordLength == 0){
@@ -258,7 +258,7 @@ void Therver::HandleLoginFromClient(ting::Ref< ::Client>& c, ting::Array<ting::b
 
 
 
-void Therver::HandlePlayingDataFromClient(ting::Ref< ::Client>& c, ting::Array<ting::byte> d){
+void Therver::HandlePlayingDataFromClient(ting::Ref< ::Client>& c, ting::Array<ting::u8> d){
 	//if client is not logged in then ignore that
 	if(c->IsNotLoggedIn()){
 		TRACE_AND_LOG(<< "[!WARN] Therver::HandlePlayingDataFromClient(): client is not logged in" << std::endl)
