@@ -82,12 +82,12 @@ public:
 	void OnClientDisconnected(ting::Ref<cliser::Client>& client);
 
 	//override
-	void OnDataReceivedFromClient(ting::Ref<cliser::Client>& client, ting::Array<ting::byte> d);
+	void OnDataReceivedFromClient(ting::Ref<cliser::Client>& client, ting::Array<ting::u8> d);
 
 private:
-	void HandleRegisterFromClient(ting::Ref<Client>& c, ting::Array<ting::byte> d);
-	void HandleLoginFromClient(ting::Ref<Client>& c, ting::Array<ting::byte> p);
-	void HandlePlayingDataFromClient(ting::Ref<Client>& c, ting::Array<ting::byte> d);
+	void HandleRegisterFromClient(ting::Ref<Client>& c, ting::Array<ting::u8> d);
+	void HandleLoginFromClient(ting::Ref<Client>& c, ting::Array<ting::u8> p);
+	void HandlePlayingDataFromClient(ting::Ref<Client>& c, ting::Array<ting::u8> d);
 	void HandleListenNextCommandFromClient(ting::Ref<Client>& c);
 	void HandleStopListeningCommandFromClient(ting::Ref<Client>& c);
 
@@ -131,13 +131,13 @@ class NetworkDataFromClientReceivedMessage : public ting::Message{
 
 	ting::Ref<Client> client;
 
-	ting::Array<ting::byte> data;
+	ting::Array<ting::u8> data;
 
 public:
 	NetworkDataFromClientReceivedMessage(
 			Therver* thread,
 			ting::Ref<Client>& clt,
-			ting::Array<ting::byte> d
+			ting::Array<ting::u8> d
 		) :
 			thr(thread),
 			client(clt),
