@@ -104,16 +104,16 @@ public:
 
 
 	//override
-	virtual ting::uint Read(
-			ting::Buffer<ting::byte>& buf,
-			ting::uint numBytesToRead = 0,
-			ting::uint offset = 0
+	virtual unsigned Read(
+			ting::Buffer<ting::u8>& buf,
+			unsigned numBytesToRead = 0,
+			unsigned offset = 0
 		)
 	{
 		if(!this->IsOpened())
 			throw File::Exc("file is not opened, cannot read");
 
-		ting::uint actualNumBytesToRead =
+		unsigned actualNumBytesToRead =
 				numBytesToRead == 0 ? buf.SizeInBytes() : numBytesToRead;
 
 		if(actualNumBytesToRead > buf.SizeInBytes() - offset)
@@ -121,7 +121,7 @@ public:
 
 		ASSERT(actualNumBytesToRead + offset <= buf.SizeInBytes())
 		ASSERT(this->handle)
-        ting::uint numBytesRead = fread(&buf[offset], 1, actualNumBytesToRead, this->handle);
+        unsigned numBytesRead = fread(&buf[offset], 1, actualNumBytesToRead, this->handle);
         if(numBytesRead != actualNumBytesToRead){//something happened
             if(!feof(this->handle))
 				throw File::Exc("fread() error");//if it is not an EndOfFile then it is error
@@ -133,10 +133,10 @@ public:
 
 	//override
 	//returns number of bytes actually written
-	virtual ting::uint Write(
-			const ting::Buffer<ting::byte>& buf,
-			ting::uint numBytesToWrite = 0,
-			ting::uint offset = 0
+	virtual unsigned Write(
+			const ting::Buffer<ting::u8>& buf,
+			unsigned numBytesToWrite = 0,
+			unsigned offset = 0
 		)
 	{
 		if(!this->IsOpened())
@@ -145,7 +145,7 @@ public:
 		if(this->ioMode != WRITE)
 			throw File::Exc("file is opened, but not in WRITE mode");
 
-		ting::uint actualNumBytesToWrite =
+		unsigned actualNumBytesToWrite =
 				numBytesToWrite == 0 ? buf.SizeInBytes() : numBytesToWrite;
 
 		if(actualNumBytesToWrite > buf.SizeInBytes() - offset)
@@ -153,7 +153,7 @@ public:
 
 		ASSERT(actualNumBytesToWrite + offset <= buf.SizeInBytes())
 		ASSERT(this->handle)
-		ting::uint bytesWritten = fwrite(&buf[offset], 1, actualNumBytesToWrite, this->handle);
+		unsigned bytesWritten = fwrite(&buf[offset], 1, actualNumBytesToWrite, this->handle);
 		if(bytesWritten != actualNumBytesToWrite)//something bad has happened
 			throw File::Exc("fwrite error");
 
@@ -163,7 +163,7 @@ public:
 
 
 	//override
-	virtual void SeekFwd(ting::uint numBytesToSeek){
+	virtual void SeekFwd(unsigned numBytesToSeek){
 		if(!this->IsOpened())
 			throw File::Exc("file is not opened, cannot seek");
 
