@@ -111,20 +111,20 @@ public:
 	}
 
 	//returns number of bytes actually read
-	virtual ting::uint Read(
-			ting::Buffer<ting::byte>& buf,
-			ting::uint numBytesToRead = 0,
-			ting::uint offset = 0
+	virtual unsigned Read(
+			ting::Buffer<ting::u8>& buf,
+			unsigned numBytesToRead = 0,
+			unsigned offset = 0
 		) = 0;
 
 	//returns number of bytes actually written
-	virtual ting::uint Write(
-			const ting::Buffer<ting::byte>& buf,
-			ting::uint numBytesToWrite = 0,
-			ting::uint offset = 0
+	virtual unsigned Write(
+			const ting::Buffer<ting::u8>& buf,
+			unsigned numBytesToWrite = 0,
+			unsigned offset = 0
 		) = 0;
 
-	virtual void SeekFwd(ting::uint numBytesToSeek){
+	virtual void SeekFwd(unsigned numBytesToSeek){
 		throw File::Exc("Seek forward is not supported");
 	}
 
@@ -132,11 +132,11 @@ public:
 		throw File::Exc("Make directory is not supported");
 	}
 private:
-	static inline ting::uint DReadBlockSize(){
+	static inline unsigned DReadBlockSize(){
 		return 4096;
 	}
 public:
-	ting::Array<ting::byte> LoadWholeFileIntoMemory(){
+	ting::Array<ting::u8> LoadWholeFileIntoMemory(){
 		if(this->IsOpened())
 			throw File::Exc("file should not be opened");
 
@@ -150,15 +150,15 @@ public:
 		TRACE(<< "File opened" <<std::endl)
 
 		//two arrays
-		ting::Array<ting::byte> a(DReadBlockSize()); //start with 4kb
-		ting::Array<ting::byte> b;
+		ting::Array<ting::u8> a(DReadBlockSize()); //start with 4kb
+		ting::Array<ting::u8> b;
 
 		//two pointers
-		ting::Array<ting::byte> *currArr = &a;
-		ting::Array<ting::byte> *freeArr = &b;
+		ting::Array<ting::u8> *currArr = &a;
+		ting::Array<ting::u8> *freeArr = &b;
  
-		ting::uint numBytesRead = 0;
-		ting::uint numBytesReadLastOp = 0;
+		unsigned numBytesRead = 0;
+		unsigned numBytesReadLastOp = 0;
 		for(;;){
 			if( currArr->Size() < (numBytesRead + DReadBlockSize()) ){
 				freeArr->Init( currArr->Size() + DReadBlockSize() );
