@@ -102,9 +102,9 @@ void ThNetworkThread::SendLoginToServer_ts(
 	ASSERT(username.size() < 1000)
 	ASSERT(password.size() < 1000)
 
-	ting::Array<ting::byte> p(1 + 2 + username.size() + 2 + password.size());//packet
+	ting::Array<ting::u8> p(1 + 2 + username.size() + 2 + password.size());//packet
 
-	ting::uint i = 0;
+	unsigned i = 0;
 
 	ASSERT(i < p.Size())
 	p[i] = 0;//login message ID
@@ -138,7 +138,7 @@ void ThNetworkThread::SendLoginToServer_ts(
 
 
 void ThNetworkThread::SendStopListeningToServer_ts(){
-	Array<byte> p(1);
+	Array<ting::u8> p(1);
 	p[0] = 0x02;
 
 	this->SendData_ts(p);
@@ -242,7 +242,7 @@ void ThNetworkThread::OnDisconnect(){
 
 
 //override
-void ThNetworkThread::OnDataReceived(ting::Array<ting::byte> data){
+void ThNetworkThread::OnDataReceived(ting::Array<ting::u8> data){
 	TRACE(<<"ThNetworkThread::OnDataReceived(): " << data.SizeInBytes() << " bytes" << std::endl)
 	this->mt->PushMessage(
 			ting::Ptr<ting::Message>(
@@ -319,7 +319,7 @@ void MusicActionMessage::Handle(){
 			this->mt->musicActionsBuffer.push_back(0x00);
 
 			//push timestamp
-			for(ting::uint i = 0; i < sizeof(u32); ++i)
+			for(unsigned i = 0; i < sizeof(u32); ++i)
 				this->mt->musicActionsBuffer.push_back(0);
 			ting::ToNetworkFormat32(
 					this->timeStamp,
@@ -331,7 +331,7 @@ void MusicActionMessage::Handle(){
 
 			//push frequency
 			ASSERT(sizeof(float) == sizeof(u32))
-			for(ting::uint i = 0; i < sizeof(u32); ++i)
+			for(unsigned i = 0; i < sizeof(u32); ++i)
 				this->mt->musicActionsBuffer.push_back(0);
 			ting::ToNetworkFormat32(
 					*reinterpret_cast<u32*>(&this->freq),
@@ -345,7 +345,7 @@ void MusicActionMessage::Handle(){
 			this->mt->musicActionsBuffer.push_back(0x01);
 
 			//push timestamp
-			for(ting::uint i = 0; i < sizeof(u32); ++i)
+			for(unsigned i = 0; i < sizeof(u32); ++i)
 				this->mt->musicActionsBuffer.push_back(0);
 			ting::ToNetworkFormat32(
 					this->timeStamp,
@@ -366,7 +366,7 @@ void MainThread::SendMusicActionsBufferToServer(){
 		return;
 	}
 
-	Array<byte> buf(this->musicActionsBuffer.size());
+	Array<ting::u8> buf(this->musicActionsBuffer.size());
 
 	//set number of action commands in buffer
 	ting::ToNetworkFormat16(
@@ -450,7 +450,7 @@ void StopListeningMessage::Handle(){
 
 
 void ThNetworkThread::SendListenNextToServer_ts(){
-	Array<byte> p(1);
+	Array<ting::u8> p(1);
 
 	p[0] = 0x01;
 
@@ -578,7 +578,7 @@ ting::u32 MainThread::ReconnectTimer::OnExpire(){
 
 
 
-void MainThread::HandleLoginResultFromServer(ting::Array<ting::byte> p){
+void MainThread::HandleLoginResultFromServer(ting::Array<ting::u8> p){
 	TRACE(<<"MainThread::HandleLoginResultFromServer(): invoked"<<std::endl)
 
 	ASSERT(p[0] == 0)// 0 = login result
@@ -604,7 +604,7 @@ void MainThread::HandleLoginResultFromServer(ting::Array<ting::byte> p){
 
 
 
-void MainThread::HandleListeningMusicDataFromServer(ting::Array<ting::byte> p){
+void MainThread::HandleListeningMusicDataFromServer(ting::Array<ting::u8> p){
 	if(!this->isListening){
 		//not in listening state, ignore packet
 		return;
@@ -615,8 +615,8 @@ void MainThread::HandleListeningMusicDataFromServer(ting::Array<ting::byte> p){
 
 
 
-void MainThread::HandlePlayerSwitchMessageFromServer(ting::Array<ting::byte> p){
-	ting::uint i = 0;
+void MainThread::HandlePlayerSwitchMessageFromServer(ting::Array<ting::u8> p){
+	unsigned i = 0;
 
 	if(i + 1 > p.Size()){
 		//bad formed packet, ignore
@@ -637,7 +637,7 @@ void MainThread::HandlePlayerSwitchMessageFromServer(ting::Array<ting::byte> p){
 			ASSERT_INFO(false, "bad formed packet")
 			return;
 		}
-		ting::uint unLen = ting::FromNetworkFormat16(&p[i]);
+		unsigned unLen = ting::FromNetworkFormat16(&p[i]);
 		i += 2;
 
 		if(unLen == 0){
@@ -663,7 +663,7 @@ void MainThread::HandlePlayerSwitchMessageFromServer(ting::Array<ting::byte> p){
 
 
 
-void MainThread::HandleStopListeningMessageFromServer(ting::Array<ting::byte> p){
+void MainThread::HandleStopListeningMessageFromServer(ting::Array<ting::u8> p){
 	if(p.Size() < 1){
 		//bad formed packet, ignore
 		ASSERT_INFO(false, "bad formed packet")
