@@ -41,7 +41,7 @@ public:
 	{}
 
 	//override
-	void OnDataReceived(ting::Array<ting::byte> data);
+	void OnDataReceived(ting::Array<ting::u8> data);
 
 	//override
 	void OnConnect(EConnectFailReason failReason);
@@ -203,8 +203,8 @@ private:
 	//indicates listening state
 	bool isListening;
 
-	ting::uint numActionsInBuffer;
-	std::vector<ting::byte> musicActionsBuffer;
+	unsigned numActionsInBuffer;
+	std::vector<ting::u8> musicActionsBuffer;
 
 	void SendMusicActionsBufferToServer();
 
@@ -227,13 +227,13 @@ public:
 
 private:
 
-	void HandleLoginResultFromServer(ting::Array<ting::byte> p);
+	void HandleLoginResultFromServer(ting::Array<ting::u8> p);
 
-	void HandleListeningMusicDataFromServer(ting::Array<ting::byte> p);
+	void HandleListeningMusicDataFromServer(ting::Array<ting::u8> p);
 
-	void HandlePlayerSwitchMessageFromServer(ting::Array<ting::byte> p);
+	void HandlePlayerSwitchMessageFromServer(ting::Array<ting::u8> p);
 
-	void HandleStopListeningMessageFromServer(ting::Array<ting::byte> p);
+	void HandleStopListeningMessageFromServer(ting::Array<ting::u8> p);
 };
 //==============================================================================
 //==============================================================================
@@ -280,10 +280,10 @@ public:
 class NetworkDataFromServerMessage : public ting::Message{
 	MainThread *mt;//this message should hold reference to the thread this message is sent to
 
-	ting::Array<ting::byte> data;
+	ting::Array<ting::u8> data;
 
 public:
-	NetworkDataFromServerMessage(MainThread* clientMainThread, ting::Array<ting::byte> d) :
+	NetworkDataFromServerMessage(MainThread* clientMainThread, ting::Array<ting::u8> d) :
 			mt(clientMainThread),
 			data(d)
 	{
