@@ -28,7 +28,7 @@ PlaybackThread::PlaybackThread() :
 
 //retuns true if data is not corrupted
 //static
-bool PlaybackThread::ParseMusicData(Array<MusicAction>& ma, const byte* dataStart, const byte* const dataEnd){
+bool PlaybackThread::ParseMusicData(Array<MusicAction>& ma, const ting::u8* dataStart, const ting::u8* const dataEnd){
 	ASSERT(ma.Size() > 0)
 	ASSERT(dataStart < dataEnd)
 
@@ -67,7 +67,7 @@ bool PlaybackThread::ParseMusicData(Array<MusicAction>& ma, const byte* dataStar
 
 
 void PlaybackThread::Run(){
-	ting::byte curInstrumentCode;
+	ting::u8 curInstrumentCode;
 //	Array<MusicAction> curMusicData;
 	
 	MusicAction *curMusicAction;
@@ -94,8 +94,8 @@ void PlaybackThread::Run(){
 				continue;
 			}
 
-			byte *startOfMusicData;
-			byte *endOfMusicData;
+			ting::u8 *startOfMusicData;
+			ting::u8 *endOfMusicData;
 			ASSERT(this->musicDataQueue.size() > 0)
 			ASSERT(this->musicDataQueue.front().SizeInBytes() >= 4)
 			startOfMusicData = this->musicDataQueue.front().Begin();
@@ -221,7 +221,7 @@ void PlaybackThread::HandlePlayerSwitch_ts(){
 
 
 
-void PlaybackThread::PushNewPlaybackData_ts(ting::Array<ting::byte> data){
+void PlaybackThread::PushNewPlaybackData_ts(ting::Array<ting::u8> data){
 	if(data.SizeInBytes() < 4){
 		//ignore chunks without any music actions.
 		//Normally, there should be no such chunks at all.
