@@ -19,7 +19,7 @@
 //==============================================================================
 //==============================================================================
 //==============================================================================
-class PlaybackThread : public ting::Thread{
+class PlaybackThread : public ting::MsgThread{
 	friend class PushMusicDataMessage;
 	friend class PlayerSwitchMessage;
 	friend class ResetPlaybackMessage;
@@ -28,7 +28,7 @@ class PlaybackThread : public ting::Thread{
 	ting::Ref<aumiks::Instrument> instr;//current instrument
 	ting::Ref<aumiks::Instrument::Channel> ch;
 
-	std::deque<ting::Array<ting::byte> > musicDataQueue;
+	std::deque<ting::Array<ting::u8> > musicDataQueue;
 
 	bool playerHasSwitched;
 
@@ -38,9 +38,9 @@ class PlaybackThread : public ting::Thread{
 	};
 
 	struct MusicAction{
-		ting::byte id;
+		ting::u8 id;
 		ting::u32 timestamp;
-		ting::byte volume;
+		ting::u8 volume;
 		float freq;
 	};
 
@@ -54,15 +54,15 @@ public:
 
 	void ResetPlayback_ts();
 
-	void PushNewPlaybackData_ts(ting::Array<ting::byte> data);
+	void PushNewPlaybackData_ts(ting::Array<ting::u8> data);
 
 	void HandlePlayerSwitch_ts();
 private:
 
 	static bool ParseMusicData(
 			ting::Array<MusicAction>& ma,
-			const ting::byte* dataStart,
-			const ting::byte* const dataEnd
+			const ting::u8* dataStart,
+			const ting::u8* const dataEnd
 		);
 };
 //==============================================================================
@@ -74,12 +74,12 @@ private:
 class PushMusicDataMessage : public ting::Message{
 	PlaybackThread* t;
 
-	ting::Array<ting::byte> data;
+	ting::Array<ting::u8> data;
 
 public:
 	PushMusicDataMessage(
 			PlaybackThread* thread,
-			ting::Array<ting::byte> musicData
+			ting::Array<ting::u8> musicData
 		) :
 			t(thread),
 			data(musicData)
