@@ -44,7 +44,7 @@ void Preferences::LoadFromFile(){
 
 	pugi::xml_document doc;
 	{
-		ting::Array<ting::byte> rawFile;
+		ting::Array<ting::u8> rawFile;
 		try{
 			rawFile = f.LoadWholeFileIntoMemory();
 		}catch(file::File::Exc &e){
@@ -64,7 +64,7 @@ void Preferences::LoadFromFile(){
 		if(!opts.empty()){
 			pugi::xml_attribute numOctavesAttr = opts.attribute(DNumOctavesAttribute);
 			if(!numOctavesAttr.empty()){
-				ting::uint num = numOctavesAttr.as_uint();
+				unsigned num = numOctavesAttr.as_uint();
 				if(num != 0 && num <= 3)//TODO: check for that inside of this->SetNumOctaves()
 					this->SetNumOctaves(num);
 			}
@@ -206,7 +206,7 @@ void Preferences::SaveToFile(){
 
 		//override
 		void write(const void *data, size_t size){
-			ting::Array<ting::byte> buf(size);
+			ting::Array<ting::u8> buf(size);
 			memcpy(buf.Buf(), data, size);
 			f.Write(buf);
 		}
