@@ -39,7 +39,7 @@ THE SOFTWARE. */
 #include "utils.hpp"
 
 
-inline ting::uint DHighestOctave(){
+inline unsigned DHighestOctave(){
 	return 7;
 }
 
@@ -84,9 +84,9 @@ public:
 
 	//Theremin settings
 private:
-	ting::uint numOctaves;
+	unsigned numOctaves;
 
-	ting::uint basePitch;//step number starting from A0 (27.5Hz)
+	unsigned basePitch;//step number starting from A0 (27.5Hz)
 
 	bool lockCurrentOctave;
 
@@ -94,20 +94,20 @@ private:
 	E_Timbre timbre;
 public:
 
-	inline ting::uint GetNumOctaves()const{
+	inline unsigned GetNumOctaves()const{
 		return this->numOctaves;
 	}
 
-	void SetNumOctaves(ting::uint numberOfOctaves){
+	void SetNumOctaves(unsigned numberOfOctaves){
 		this->numOctaves = numberOfOctaves;
 		this->ClampBasePitch();
 	}
 
-	inline ting::uint GetBasePitch()const{
+	inline unsigned GetBasePitch()const{
 		return this->basePitch;
 	}
 
-	void SetBasePitch(ting::uint newBasePitch){
+	void SetBasePitch(unsigned newBasePitch){
 		this->basePitch = newBasePitch;
 		this->ClampBasePitch();
 	}
@@ -139,16 +139,16 @@ private:
 
 	//keyboard view settings
 private:
-	ting::uint kbScrPos;//screen position
+	unsigned kbScrPos;//screen position
 
 	E_Timbre kbTimbre;
 
 public:
-	inline ting::uint GetKbScrPos()const{
+	inline unsigned GetKbScrPos()const{
 		return this->kbScrPos;
 	}
 
-	void SetKbScrPos(ting::uint newScrPos){
+	void SetKbScrPos(unsigned newScrPos){
 		this->kbScrPos = newScrPos;
 	}
 
