@@ -168,7 +168,7 @@ bool ThereminWindow::ThereminView::OnExposeEvent(GdkEventExpose* event){
 	c->select_font_face("Sans", Cairo::FONT_SLANT_NORMAL, Cairo::FONT_WEIGHT_NORMAL);
 	c->set_font_size(50.0);
 
-	for(ting::uint i = 0; i < Preferences::Inst().GetNumOctaves(); ++i){
+	for(unsigned i = 0; i < Preferences::Inst().GetNumOctaves(); ++i){
 		c->save();
 		c->translate(0, (i * height) / Preferences::Inst().GetNumOctaves());
 		ThereminWindow::ThereminView::DrawOctave(
@@ -204,9 +204,9 @@ static const char* notes[] = {
 //static
 void ThereminWindow::ThereminView::DrawOctave(
 		Cairo::RefPtr<Cairo::Context> c,
-		ting::uint w,
-		ting::uint h,
-		ting::uint basePitch
+		unsigned w,
+		unsigned h,
+		unsigned basePitch
 	)
 {
 	float step = float(w) / 12.0f;
@@ -218,7 +218,7 @@ void ThereminWindow::ThereminView::DrawOctave(
 	c->rectangle(0, 0, w, h);
 	c->fill();
 
-	for(ting::uint i = 0, n = basePitch % 12; i < 12; ++i, ++n){
+	for(unsigned i = 0, n = basePitch % 12; i < 12; ++i, ++n){
 		if(n >= 12)
 			n -= 12;
 
@@ -354,13 +354,13 @@ ThereminWindow::FreqVol ThereminWindow::CalcFreqAndVol(
 	FreqVol ret;
 	x -= width / real(24); //subtract half of halfstep onscreen width
 
-	ting::uint octHeight = ting::uint(height / real(Preferences::Inst().GetNumOctaves()));
+	unsigned octHeight = unsigned(height / real(Preferences::Inst().GetNumOctaves()));
 
 	ting::ClampBottom(y, real(0));
 	ASSERT(y >= real(0))
 
 	//find the screen octave number of the touched octave
-	ting::uint touchedOctave = ting::uint(y) / octHeight;
+	unsigned touchedOctave = unsigned(y) / octHeight;
 	ting::ClampTop(touchedOctave, Preferences::Inst().GetNumOctaves() - 1);
 
 	if(Preferences::Inst().GetLockCurrentOctave()){
@@ -371,7 +371,7 @@ ThereminWindow::FreqVol ThereminWindow::CalcFreqAndVol(
 		this->curOctave = touchedOctave;
 	}
 
-	ting::uint octavesShift = (Preferences::Inst().GetNumOctaves() - 1 - this->curOctave) * 12;
+	unsigned octavesShift = (Preferences::Inst().GetNumOctaves() - 1 - this->curOctave) * 12;
 
 	ret.freq = CalcFreq(
 			real(27.5f),
