@@ -1,6 +1,6 @@
 /* The MIT License:
 
-Copyright (c) 2009 Ivan Gagis
+Copyright (c) 2010 Ivan Gagis
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -34,9 +34,9 @@ THE SOFTWARE. */
 #include <gtkmm/drawingarea.h>
 
 #include <ting/types.hpp>
-#include <ting/Fixed.hpp>
 #include <aumiks/synth/synth.hpp>
 
+#include "Fixed.hpp"
 #include "BasicWindow.hpp"
 #include "utils.hpp"
 #include "Preferences.hpp"
@@ -52,7 +52,7 @@ class ThereminWindow : public BasicWindow{
 
 	MonotonicInstrumentHolder instr;
 
-	ting::uint curOctave;//for locking to first tapped octave
+	unsigned curOctave;//for locking to first tapped octave
 
 	float tappedX;
 
@@ -62,7 +62,7 @@ class ThereminWindow : public BasicWindow{
 
 		bool OnExposeEvent(GdkEventExpose* event);
 
-		static void DrawOctave(Cairo::RefPtr<Cairo::Context> c, ting::uint w, ting::uint h, ting::uint basePitch);
+		static void DrawOctave(Cairo::RefPtr<Cairo::Context> c, unsigned w, unsigned h, unsigned basePitch);
 	};
 public:
 	ThereminWindow();
@@ -79,7 +79,7 @@ public:
 
 	void ShowOptionsDialog();
 
-	inline ting::uint PitchRange()const{
+	inline unsigned PitchRange()const{
 		return Preferences::Inst().GetNumOctaves() * 12;
 	};
 
