@@ -39,34 +39,34 @@ namespace aumiks{
 //base class for audio backends
 class AudioBackend{
 protected:
-	ting::uint bufSizeInFrames;
-	ting::uint sampleSizeInBytes;
-	ting::uint numChannels;
+	unsigned bufSizeInFrames;
+	unsigned sampleSizeInBytes;
+	unsigned numChannels;
 public:
 
 	virtual ~AudioBackend(){};
 
-	inline ting::uint BufferSizeInFrames()const{
+	inline unsigned BufferSizeInFrames()const{
 		return this->bufSizeInFrames;
 	}
 
-	inline ting::uint BufferSizeInSamples()const{
+	inline unsigned BufferSizeInSamples()const{
 		return this->bufSizeInFrames * this->numChannels;
 	}
 
-	inline ting::uint BufferSizeInBytes()const{
+	inline unsigned BufferSizeInBytes()const{
 		return this->BufferSizeInFrames() * this->FrameSizeInBytes();
 	}
 
-	inline ting::uint SampleSizeInBytes()const{
+	inline unsigned SampleSizeInBytes()const{
 		return this->sampleSizeInBytes;
 	}
 
-	inline ting::uint FrameSizeInBytes()const{
+	inline unsigned FrameSizeInBytes()const{
 		return this->SampleSizeInBytes() * this->numChannels;
 	}
 
-	virtual void Write(const ting::Buffer<ting::byte>& buf) = 0;
+	virtual void Write(const ting::Buffer<ting::u8>& buf) = 0;
 };
 
 }//~namespace
