@@ -44,7 +44,7 @@ class PulseAudioBackend : public AudioBackend{
 	 pa_simple *handle;
 
 public:
-	PulseAudioBackend(ting::uint requestedBufferSizeInFrames){
+	PulseAudioBackend(unsigned requestedBufferSizeInFrames){
 		//TODO: get actual buffer size from pulseaudio
 		this->bufSizeInFrames = requestedBufferSizeInFrames;
 		this->sampleSizeInBytes = 2;
@@ -103,7 +103,7 @@ public:
 
 
 	//override
-	void Write(const ting::Buffer<ting::byte>& buf){
+	void Write(const ting::Buffer<ting::u8>& buf){
 		ASSERT(buf.Size() == this->BufferSizeInBytes())
 
 		if(pa_simple_write(
