@@ -43,7 +43,7 @@ namespace aumiks{
 
 class DelayAllPass1{
 	ting::Array<aumiks::real> line;
-	ting::uint inIndex, outIndex;
+	unsigned inIndex, outIndex;
 
 	aumiks::real delay;
 	aumiks::real eta;
@@ -53,7 +53,7 @@ class DelayAllPass1{
 
 	void SetMaxDelay(aumiks::real delayToSet){
 		ASSERT(delayToSet > 0.5)
-		this->line.Init(ting::uint(delayToSet + 1));
+		this->line.Init(unsigned(delayToSet + 1));
 	}
 public:
 	//default constructor
@@ -82,7 +82,7 @@ public:
 	}
 
 	void Clear(){
-		for(ting::uint i = 0; i < this->line.Size(); ++i)
+		for(unsigned i = 0; i < this->line.Size(); ++i)
 			line[i] = 0;
 		this->y = 0;
 		this->prevX = 0;
@@ -101,7 +101,7 @@ public:
 
 		ASSERT(this->line.Size() > 0)
 
-		ting::uint lineLength = this->line.Size() - 1;
+		unsigned lineLength = this->line.Size() - 1;
 
 		if(delayToSet > lineLength){
 			ASSERT(this->inIndex < this->line.Size())
@@ -119,7 +119,7 @@ public:
 		if(outIdx < 0)
 			outIdx += this->line.Size();
 
-		this->outIndex = ting::uint(outIdx);//integer part of the delay
+		this->outIndex = unsigned(outIdx);//integer part of the delay
 
 		this->delta = aumiks::real(1) + this->outIndex - outIdx;//fractional part of the delay
 
