@@ -67,7 +67,7 @@ public:
 		this->Clear();
 	}
 
-	Filter(ting::uint numACoefs, ting::uint numBCoefs) :
+	Filter(unsigned numACoefs, unsigned numBCoefs) :
 			a(numACoefs),
 			b(numBCoefs),
 			x(a.Size()),
@@ -80,9 +80,9 @@ public:
 	virtual ~Filter(){}
 
 	void Clear(){
-		for(ting::uint i = 0; i < this->x.Size(); ++i)
+		for(unsigned i = 0; i < this->x.Size(); ++i)
 			this->x[i] = aumiks::real(0);
-		for(ting::uint i = 0; i < this->y.Size(); ++i)
+		for(unsigned i = 0; i < this->y.Size(); ++i)
 			this->y[i] = aumiks::real(0);
 	}
 
@@ -95,14 +95,14 @@ public:
 		this->x[0] = sample;
 
 		//TODO: use iterator pointers instead of indexes
-		for(ting::uint k = this->b.Size() - 1; k > 0; --k){
+		for(unsigned k = this->b.Size() - 1; k > 0; --k){
 			this->y[0] += this->b[k] * this->x[k];
 			this->x[k] = this->x[k - 1];
 		}
 		this->y[0] += this->b[0] * this->x[0];
 
 		//TODO: use iterator pointers instead of indexes
-		for(ting::uint i = this->a.Size() - 1; i > 0; --i){
+		for(unsigned i = this->a.Size() - 1; i > 0; --i){
 			this->y[0] -= this->a[i] * this->y[i];
 			this->y[i] = this->y[i - 1];
 		}
