@@ -29,8 +29,7 @@ THE SOFTWARE. */
  * a reference while creating this class.
  */
 
-#ifndef M_NoiseGen_hpp
-#define M_NoiseGen_hpp
+#pragma once
 
 #include <cstdlib>
 #include <ting/debug.hpp>
@@ -47,4 +46,3 @@ public:
 };
 
 }//~namespace
-#endif //~once
