@@ -52,7 +52,7 @@ bool SineWaveInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 
 	bool stopPlaying = false;
 	bool quit;
-	ting::uint i = 0;//current sample
+	unsigned i = 0;//current sample
 	do{//while(!quit)
 		quit = true;
 		switch(this->envPhase){
@@ -232,7 +232,7 @@ bool PluckedStringInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 			break;
 	}
 
-	for(ting::uint i=0; i < mixBuf.Size();){
+	for(unsigned i=0; i < mixBuf.Size();){
 		float s = 2 * this->pluckedString.Tick();
 		s32 smp = s32(0x7fff * s);
 
@@ -271,7 +271,7 @@ PianoInstrument::PianoInstrument(){
 	memcpy(x.Buf(), xx, x.SizeInBytes());
 	memcpy(y.Buf(), yy, y.SizeInBytes());
 
-	for(ting::uint i = 0; i < y.Size(); ++i){
+	for(unsigned i = 0; i < y.Size(); ++i){
 		x[i] /= 2;
 		y[i] /= 2;
 	}
@@ -279,7 +279,7 @@ PianoInstrument::PianoInstrument(){
 	this->pianoPulseSample = Sample::GenerateFromFourier(
 			x,
 			y,
-			ting::uint((44100.0f / 25.0f) * 1.0f),
+			unsigned((44100.0f / 25.0f) * 1.0f),
 			25
 		);
 }
@@ -316,7 +316,7 @@ bool PianoInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 			break;
 	}
 
-	for(ting::uint i=0; i < mixBuf.Size();){
+	for(unsigned i=0; i < mixBuf.Size();){
 		float s = this->pluckedString.Tick(this->pulseGen.Tick());
 		s32 smp = s32(0x7fff * s);
 
@@ -353,7 +353,7 @@ bool BowedInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 		ret = true;
 	}
 
-	for(ting::uint i=0; i < mixBuf.Size();){
+	for(unsigned i=0; i < mixBuf.Size();){
 		float s = this->bowed.Tick();
 		s32 smp = s32(0x7fff * s);
 
@@ -392,7 +392,7 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 
 	bool stopPlaying = false;
 	bool quit;
-	ting::uint i = 0;//current sample index
+	unsigned i = 0;//current sample index
 	
 	do{//while(!quit)
 		quit = true;
@@ -409,10 +409,10 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 					real attack = this->curTime / this->attackTime;
 					this->releaseFromLevel = attack;
 
-					ASSERT(ting::uint(this->curPhase) < sample.Size())
-					s32 smp = s32(real(0x7fff) * attack * sample[ting::uint(this->curPhase)]);
+					ASSERT(unsigned(this->curPhase) < sample.Size())
+					s32 smp = s32(real(0x7fff) * attack * sample[unsigned(this->curPhase)]);
 					this->curPhase += this->phaseStep;
-					if(ting::uint(this->curPhase) >= sample.Size()){
+					if(unsigned(this->curPhase) >= sample.Size()){
 						this->curPhase -= real(sample.Size());
 					}
 
@@ -443,10 +443,10 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 					real decay = real(1) - (real(1) - sustainLevel) * (this->curTime / this->decayTime);
 					this->releaseFromLevel = decay;
 
-					ASSERT(ting::uint(this->curPhase) < sample.Size())
-					s32 smp = s32(real(0x7fff) * decay * sample[ting::uint(this->curPhase)]);
+					ASSERT(unsigned(this->curPhase) < sample.Size())
+					s32 smp = s32(real(0x7fff) * decay * sample[unsigned(this->curPhase)]);
 					this->curPhase += this->phaseStep;
-					if(ting::uint(this->curPhase) >= sample.Size()){
+					if(unsigned(this->curPhase) >= sample.Size()){
 						this->curPhase -= real(sample.Size());
 					}
 					
@@ -476,15 +476,15 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 				this->releaseFromLevel = sustainLevel;
 				for(; i < mixBuf.Size();){
 
-					ASSERT(ting::uint(this->curPhase) < sample.Size())
-					s32 smp = s32(real(0x7fff) * sustainLevel * sample[ting::uint(this->curPhase)]);
+					ASSERT(unsigned(this->curPhase) < sample.Size())
+					s32 smp = s32(real(0x7fff) * sustainLevel * sample[unsigned(this->curPhase)]);
 					this->curPhase += this->phaseStep;
-					if(ting::uint(this->curPhase) >= sample.Size()){
+					if(unsigned(this->curPhase) >= sample.Size()){
 						this->curPhase -= real(sample.Size());
 					}
 
 //						TRACE(<<"t =" << this->t)
-//						TRACE(<<"s =" << sample[ting::uint(this->curPhase)] << std::endl)
+//						TRACE(<<"s =" << sample[unsigned(this->curPhase)] << std::endl)
 //						TRACE(<<"smp =" << smp << std::endl)
 
 					//interpolate volume
@@ -504,10 +504,10 @@ bool SampledInstrument::Channel::MixToMixBuf(Array<s32>& mixBuf){
 				for(; i < mixBuf.Size();){
 					real release = this->releaseFromLevel * (real(1) - this->curTime / this->releaseTime);
 
-					ASSERT(ting::uint(this->curPhase) < sample.Size())
-					s32 smp = s32(real(0x7fff) * release * sample[ting::uint(this->curPhase)]);
+					ASSERT(unsigned(this->curPhase) < sample.Size())
+					s32 smp = s32(real(0x7fff) * release * sample[unsigned(this->curPhase)]);
 					this->curPhase += this->phaseStep;
-					if(ting::uint(this->curPhase) >= sample.Size()){
+					if(unsigned(this->curPhase) >= sample.Size()){
 						this->curPhase -= real(sample.Size());
 					}
 
@@ -594,7 +594,7 @@ Ref<aumiks::Sample> ClarinetInstrument::GenerateSample(){
 
 	//sampling rate 44100Hz, sound base freq is 25Hz
 	ret->freq = real(25);
-	ret->data.Init(44100 / ting::uint(ret->freq));//hold one period
+	ret->data.Init(44100 / unsigned(ret->freq));//hold one period
 
 	Array<real> &d = ret->data;
 
@@ -602,7 +602,7 @@ Ref<aumiks::Sample> ClarinetInstrument::GenerateSample(){
 
 	float f = D2Pi<float>() * float(ret->freq);
 
-	for(ting::uint i = 0; i < ret->data.Size(); ++i){
+	for(unsigned i = 0; i < ret->data.Size(); ++i){
 		ASSERT(i < d.Size())
 		float t = float(i) * float(1.0f / 44100.0f);
 		d[i] = real(
@@ -703,7 +703,7 @@ Ref<aumiks::Sample> ViolinInstrument::GenerateSample(){
 	Ref<Sample> ret = Sample::GenerateFromLineString(
 			x,
 			y,
-			44100 / ting::uint(25),
+			44100 / unsigned(25),
 			25
 		);
 
@@ -747,13 +747,13 @@ Ref<aumiks::Sample> SawtoothInstrument::GenerateSample(){
 	Ref<Sample> ret = Sample::GenerateFromLineString(
 			x,
 			y,
-			44100 / ting::uint(25),
+			44100 / unsigned(25),
 			25
 		);
 
 	FilterOneZero f(0.5, 0.5);
 
-	for(ting::uint i = 0; i < ret->data.Size(); ++i){
+	for(unsigned i = 0; i < ret->data.Size(); ++i){
 		ret->data[i] = f.Tick(ret->data[i]);
 	}
 
