@@ -1,6 +1,6 @@
 /* The MIT License:
 
-Copyright (c) 2009 Ivan Gagis
+Copyright (c) 2010 Ivan Gagis
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
@@ -33,7 +33,8 @@ THE SOFTWARE. */
 
 #include <ting/Array.hpp>
 #include <ting/types.hpp>
-#include <ting/Fixed.hpp>
+
+#include "Fixed.hpp"
 
 #include "../aumiks.hpp"
 
