@@ -33,7 +33,7 @@ THE SOFTWARE. */
 
 #include <ting/types.hpp>
 
-inline ting::uint DFingerFriendlyMinSize(){
+inline unsigned DFingerFriendlyMinSize(){
 	return 60;
 }
 
